@@ -1045,7 +1045,49 @@ namespace Model
     r8gn_24xlarge,
     r8gn_48xlarge,
     r8gn_metal_24xl,
-    r8gn_metal_48xl
+    r8gn_metal_48xl,
+    c8i_large,
+    c8i_xlarge,
+    c8i_2xlarge,
+    c8i_4xlarge,
+    c8i_8xlarge,
+    c8i_12xlarge,
+    c8i_16xlarge,
+    c8i_24xlarge,
+    c8i_32xlarge,
+    c8i_48xlarge,
+    c8i_96xlarge,
+    c8i_metal_48xl,
+    c8i_metal_96xl,
+    c8i_flex_large,
+    c8i_flex_xlarge,
+    c8i_flex_2xlarge,
+    c8i_flex_4xlarge,
+    c8i_flex_8xlarge,
+    c8i_flex_12xlarge,
+    c8i_flex_16xlarge,
+    r8gb_medium,
+    r8gb_large,
+    r8gb_xlarge,
+    r8gb_2xlarge,
+    r8gb_4xlarge,
+    r8gb_8xlarge,
+    r8gb_12xlarge,
+    r8gb_16xlarge,
+    r8gb_24xlarge,
+    r8gb_metal_24xl,
+    m8a_medium,
+    m8a_large,
+    m8a_xlarge,
+    m8a_2xlarge,
+    m8a_4xlarge,
+    m8a_8xlarge,
+    m8a_12xlarge,
+    m8a_16xlarge,
+    m8a_24xlarge,
+    m8a_48xlarge,
+    m8a_metal_24xl,
+    m8a_metal_48xl
   };
 
 namespace InstanceTypeMapper
