@@ -159,8 +159,8 @@ namespace Model
     bool m_dryRun{false};
     bool m_dryRunHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
 
     VerifiedAccessSseSpecificationRequest m_sseSpecification;
     bool m_sseSpecificationHasBeenSet = false;
